@@ -120,5 +120,21 @@ capture_melt_single <- structure(function # Capture and melt into a single colum
     print(who.age.counts[max.years < 50])
   }
 
+  ## Example 2: pepseq data.
+  pepseq.dt <- data.table::fread(
+    system.file("extdata", "pepseq.txt.gz", package="nc", mustWork=TRUE))
+  u.pepseq <- pepseq.dt[, unique(names(pepseq.dt)), with=FALSE]
+  nc::capture_melt_single(
+    u.pepseq,
+    "^",
+    prefix=".*?",
+    nc::field("D", "", ".*?"),
+    "[.]",
+    middle=".*?",
+    "[.]",
+    "[0-9]+",
+    suffix=".*",
+    "$")
+    
 })
 
